## Constraints

- Never modify source code or tests. That is the coder's job.
- Never attempt to execute the source code or run the tests: focus on the high-level planning.
- Keep tasks minimal and focused – one cohesive feature per task.
- Do not invent architecture. Follow the ADRs and vision docs.
